# -*- coding: utf-8 -*-

from __future__ import unicode_literals

try:
    # python 3
    from urllib.error import URLError
except ImportError:
    # legacy python
    URLError = IOError

import os

from lektor.context import get_ctx
from lektor.pluginsystem import Plugin
from markupsafe import Markup

from .translation import translate_lazy as _

TEMPLATES = {
    'full': (
        '<a rel="license" target="_blank" href="https://creativecommons.org/'
        'licenses/{type}/{version}/deed.{locale}">'
        '<img alt="{license}" style="border-width:0" src="{icon_path}" />'
        '</a><br />{message} '
        '<a rel="license" target="_blank" href="https://creativecommons.org/'
        'licenses/{type}/{version}/deed.{locale}">{license}</a>.'
    ),
    'image-only': (
        '<a rel="license" target="_blank" href="https://creativecommons.org/'
        'licenses/{type}/{version}/deed.{locale}">'
        '<img alt="{license}" style="border-width:0" src="{icon_path}" /></a>'
    ),
    'text-only': (
        '{message} '
        '<a rel="license" target="_blank" href="https://creativecommons.org/'
        'licenses/{type}/{version}/deed.{locale}">{license}</a>.'
    ),
}

LICENSES = {
    'by': {
        'type': 'by',
        'version': '4.0',
        'license_type': _('Attribution'),
    },
    'by-nc': {
        'type': 'by-nc',
        'version': '4.0',
        'license_type': _('Attribution - NonCommercial'),
    },
    'by-sa': {
        'type': 'by-sa',
        'version': '4.0',
        'license_type': _('Attribution - ShareAlike'),
    },
    'by-nc-sa': {
        'type': 'by-nc-sa',
        'version': '4.0',
        'license_type': _('Attribution - NonCommercial - ShareAlike'),
    },
    'by-nd': {
        'type': 'by-nd',
        'version': '4.0',
        'license_type': _('Attribution - NoDerivatives'),
    },
    'by-nc-nd': {
        'type': 'by-nc-nd',
        'version': '4.0',
        'license_type': _('Attribution - NonCommercial - NoDerivatives'),
    },
}

LICENSE_SIZES = {
    'normal': '88x31',
    'compact': '80x15',
}


class CreativeCommonsPlugin(Plugin):

    name = 'Creative Commons'
    description = 'Add Creative Commons license to your pages.'

    def __init__(self, env, id):
        self.locale = env.load_config().site_locale or 'en'
        _.translator.configure(self.locale)

        super(CreativeCommonsPlugin, self).__init__(env, id)

    def render_cc_license(self, type, size='normal', template='full',
                          caller=None):
        license = LICENSES[type].copy()
        license['size'] = LICENSE_SIZES[size]
        license['locale'] = self.locale
        license['message'] = _('This work is licensed under a')
        license['license'] = _(
            'Creative Commons %(license_type)s 4.0 International License',
            license
        )
        license['license_url'] = (
            'https://creativecommons.org/'
            'licenses/{type}/{version}/deed.{locale}'
        ).format(**license)
        license['icon_path'] = self.icon_path(license)

        if callable(caller):
            if caller.catch_kwargs:
                return Markup(caller(**license))
            else:
                license_subset = dict(
                    (argument_name, license[argument_name])
                    for argument_name in caller.arguments
                )

                return Markup(caller(**license_subset))

        return Markup(TEMPLATES[template].format(**license))

    def icon_path(self, license):
        icon_target_path = (
            '/static/lektor-creative-commons/{type}/{version}/{size}.png'
        ).format(**license)
        icon_source_path = os.path.join(
            os.path.dirname(__file__), 'assets', license['type'],
            license['version'], license['size'] + '.png'
        )
        ctx = get_ctx()

        @ctx.sub_artifact(
            icon_target_path, sources=[], source_obj=icon_source_path
        )
        def copy_icon(artifact):
            artifact.sources.append(artifact.dst_filename)
            artifact.replace_with_file(icon_source_path, copy=True)

        return icon_target_path

    def on_setup_env(self, **extra):
        self.env.jinja_env.globals.update(
            render_cc_license=self.render_cc_license
        )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import subprocess

from setuptools import find_packages, setup


def create_mo_files():
    data_files = []
    localedir = 'lektor_creative_commons/locales'
    po_dirs = [
        localedir + '/' + l + '/LC_MESSAGES/'
        for l in next(os.walk(localedir))[1]
    ]

    for d in po_dirs:
        mo_files = []
        po_files = [
            f for f in next(os.walk(d))[2] if os.path.splitext(f)[1] == '.po'
        ]

        for po_file in po_files:
            filename, extension = os.path.splitext(po_file)
            mo_file = filename + '.mo'
            msgfmt_cmd = 'msgfmt {} -o {}'.format(d + po_file, d + mo_file)
            subprocess.call(msgfmt_cmd, shell=True)
            mo_files.append(d + mo_file)

        data_files.append((d, mo_files))

    return data_files


with open('README.md', 'r') as f:
    README = f.read()

setup(
    name='lektor-creative-commons',
    description='Lektor plugin to add Creative Commons license to your pages',
    long_description=README,
    long_description_content_type='text/markdown',
    version='0.5.2',
    url='https://github.com/humrochagf/lektor-creative-commons',
    project_urls={
        'Documentation': (
            'https://github.com/humrochagf/lektor-creative-commons/'
            'blob/master/README.md'),
        'Source': 'https://github.com/humrochagf/lektor-creative-commons/',
        'Tracker': (
            'https://github.com/humrochagf/lektor-creative-commons/issues'),
    },
    author='Humberto Rocha',
    author_email='humrochagf@gmail.com',
    license='MIT',
    py_modules=['lektor_creative_commons'],
    entry_points={
        'lektor.plugins': [
            'creative-commons=lektor_creative_commons:CreativeCommonsPlugin',
        ]
    },
    packages=find_packages(),
    include_package_data=True,
    package_data={
        'lektor_creative_commons': ['assets/*/*/*.png']
    },
    zip_safe=False,
    data_files=create_mo_files(),
    classifiers=[
        'Framework :: Lektor',
        'Environment :: Plugins',
    ],
)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import gettext
import os
import sys

PY3 = sys.version_info > (3,)

LOCALES_DIR = os.path.join(
    os.path.dirname(os.path.abspath(__file__)),
    'locales'
)


class Translator(object):

    def configure(self, locale):
        if not os.path.exists(os.path.join(LOCALES_DIR, locale)):
            locale = 'en'

        self.lang = gettext.translation(
            'messages', localedir=LOCALES_DIR, languages=[locale])
        self.lang.install()

    def translate(self, string, arguments=None):
        if PY3:
            gettext = self.lang.gettext
        else:
            gettext = self.lang.ugettext

        translated = gettext(string)
        if arguments is not None:
            translated = translated % arguments

        return translated


class __proxy__(object):

    def __init__(self, string, translator, arguments):
        self.translator = translator
        self.string = string
        self.arguments = arguments

    def __repr__(self):
        return self.translator.translate(self.string, self.arguments)

    __str__ = __repr__


class LazyTranslator(object):

    def __init__(self):
        self.translator = Translator()

    def __call__(self, string, arguments=None):
        self.proxy = __proxy__(string, self.translator, arguments)

        return self.proxy


translate_lazy = LazyTranslator()
